# Ultrasonic Agentics Documentation

Welcome to the comprehensive documentation for **Ultrasonic Agentics** - a cutting-edge steganography framework for embedding and extracting agentic commands in multimedia content.

## 📚 Documentation Structure

### 🚀 Getting Started
- **[📖 Complete Documentation Index](index.md)** - Your starting point for all documentation
- **[📦 Installation Guide](installation.md)** - Platform-specific setup instructions
- **[📘 User Guide](user-guide.md)** - Comprehensive usage tutorials
- **[⚡ Quick Examples](../examples/README.md)** - Hands-on code examples

### 🔧 Development & Integration
- **[💻 CLI Usage Guide](cli-usage.md)** - Command-line interface and automation
- **[🔌 MCP Integration](mcp-integration.md)** - Model Context Protocol for AI assistants
- **[🌐 Complete API Reference](api-complete.md)** - Full Python and HTTP API documentation
- **[📡 REST API Guide](api-reference.md)** - HTTP endpoints and web integration
- **[👨‍💻 Developer Guide](developer-guide.md)** - Contributing and development setup
- **[📈 Advanced Usage](advanced-usage.md)** - Complex scenarios and optimization

### 🚀 Production & Operations
- **[🚀 Deployment Guide](deployment.md)** - Production deployment strategies
- **[🔒 Security Guide](security.md)** - Security hardening and compliance
- **[🛠 Troubleshooting](troubleshooting.md)** - Issue resolution and debugging

### 🏗 Technical Documentation
- **[🏗 Architecture Overview](architecture.md)** - System design and specifications
- **[📋 Changelog](../../CHANGELOG.md)** - Version history and roadmap

## 🎯 Quick Navigation by Role

### 👤 **New Users**
1. Start with [Installation Guide](installation.md)
2. Follow the [User Guide](user-guide.md)
3. Try the [Examples](../examples/README.md)

### 👨‍💻 **Developers**
1. Start with [CLI Usage Guide](cli-usage.md)
2. Configure [MCP Integration](mcp-integration.md)
3. Read [Developer Guide](developer-guide.md)
4. Explore [API Reference](api-complete.md)
5. Study [Architecture](architecture.md)

### 🚀 **DevOps/Operators**
1. Review [Deployment Guide](deployment.md)
2. Implement [Security Guide](security.md)
3. Setup [Troubleshooting](troubleshooting.md)

### 🏢 **Enterprise Users**
1. Assess [Security Guide](security.md)
2. Plan [Deployment Strategy](deployment.md)
3. Review [Compliance Requirements](security.md#compliance-considerations)

## 🔍 Find What You Need

### Looking for...

**Installation help?** → [Installation Guide](installation.md)

**Command-line usage?** → [CLI Usage Guide](cli-usage.md)

**AI assistant integration?** → [MCP Integration](mcp-integration.md)

**API documentation?** → [Complete API Reference](api-complete.md)

**Code examples?** → [Examples Directory](../examples/README.md)

**Production deployment?** → [Deployment Guide](deployment.md)

**Security information?** → [Security Guide](security.md)

**Having issues?** → [Troubleshooting Guide](troubleshooting.md)

**Want to contribute?** → [Developer Guide](developer-guide.md)

**Technical details?** → [Architecture Overview](architecture.md)

## 🌟 Key Features Documented

- **🎵 Ultrasonic Steganography** - 18-22 kHz frequency range encoding
- **🔐 Military-Grade Encryption** - AES-256-GCM authenticated encryption
- **📡 Real-time Processing** - Live audio monitoring and encoding
- **🌐 REST API** - FastAPI-based web service
- **🎬 Multi-format Support** - Audio and video file processing
- **💻 Command Line Interface** - Full-featured CLI with rich output
- **🤖 MCP Integration** - Native support for AI assistant integration
- **🚀 Production Ready** - Docker, Kubernetes, monitoring

## 📞 Getting Help

- **📖 Documentation Issues**: File issues for documentation improvements
- **🐛 Bug Reports**: Use GitHub issues for bug reports
- **💬 Questions**: Join our community discussions
- **🔒 Security Issues**: Follow responsible disclosure process

## 📈 Documentation Metrics

| Document | Purpose | Audience | Complexity |
|----------|---------|----------|------------|
| [Installation](installation.md) | Setup & Configuration | All Users | ⭐⭐ |
| [CLI Usage](cli-usage.md) | Command Line Interface | All Users | ⭐⭐ |
| [User Guide](user-guide.md) | Basic Usage | End Users | ⭐⭐ |
| [MCP Integration](mcp-integration.md) | AI Assistant Integration | Developers | ⭐⭐⭐ |
| [API Reference](api-complete.md) | Integration | Developers | ⭐⭐⭐ |
| [Developer Guide](developer-guide.md) | Contributing | Contributors | ⭐⭐⭐ |
| [Deployment](deployment.md) | Production | DevOps | ⭐⭐⭐⭐ |
| [Security](security.md) | Hardening | Security Teams | ⭐⭐⭐⭐ |
| [Architecture](architecture.md) | Technical Deep Dive | Engineers | ⭐⭐⭐⭐⭐ |

## 🤝 Contributing to Documentation

We welcome documentation improvements! See our [Developer Guide](developer-guide.md) for:

- Documentation writing standards
- Review process
- Style guidelines
- Technical writing best practices

---

*For the complete documentation experience, start with the [📖 Documentation Index](index.md)*